@@ -320,6 +320,10 @@ bool qtractorAudioClip::openAudioFile ( const QString& sFilename, int iMode )
 	if (!pBuff->open(sFilename, iMode)) {
 		delete m_pData;
 		m_pData = nullptr;
+		if (m_pFractGains) {
+			delete [] m_pFractGains;
+			m_pFractGains = nullptr;
+		}
 		return false;
 	}
 
@@ -661,6 +665,9 @@ void qtractorAudioClip::draw (
 	if (pSession == nullptr)
 		return;
 
+	if (m_pFractGains == nullptr)
+		return;
+
 	// Cache some peak data...
 	if (m_pPeak == nullptr)
 		return;
