@@ -1,7 +1,7 @@
 // qtractorAudioPeak.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -771,7 +771,8 @@ int qtractorAudioPeakFile::write (
 
 static inline unsigned char unormf ( const float x )
 {
-	const int i = int(255.0f * x);
+//	const int i = int(255.0f * x);
+	const int i = int(510.0f * x / (1.0f + x)); // slight-compression!
 	return (i > 255 ? 255 : i);
 }
 
@@ -894,10 +895,6 @@ qtractorAudioPeak::~qtractorAudioPeak (void)
 qtractorAudioPeakFile::Frame *qtractorAudioPeak::peakFrames (
 	unsigned long iFrameOffset, unsigned long iFrameLength, int width )
 {
-	// Skip empty blanks...
-	if (width < 1)
-		return nullptr;
-
 	// Try open current peak file as is...
 	if (!m_pPeakFile->openRead())
 		return nullptr;
@@ -953,15 +950,16 @@ qtractorAudioPeakFile::Frame *qtractorAudioPeak::peakFrames (
 		m_pPeakFrames = new qtractorAudioPeakFile::Frame [n2];
 		int n = 0; int i = 0;
 		while (n < n2) {
-			const int i2 = (n * p1) / w2;
+			const int i2 = iChannels * (((n + iChannels) * p1) / n2);
+			if (i2 >= n1)
+				break;
 			for (unsigned short k = 0; k < iChannels; ++k) {
-				qtractorAudioPeakFile::Frame *pNewFrame = &m_pPeakFrames[n++];
-				qtractorAudioPeakFile::Frame *pOldFrame = &pPeakFrames[i + k];
-				pNewFrame->max = pOldFrame->max;
-				pNewFrame->min = pOldFrame->min;
-				pNewFrame->rms = pOldFrame->rms;
-				for (int j = i + 1; j < i2; j += iChannels) {
-					pOldFrame += iChannels;
+				qtractorAudioPeakFile::Frame *pNewFrame = &m_pPeakFrames[n + k];
+				pNewFrame->max = 0;
+				pNewFrame->min = 0;
+				pNewFrame->rms = 0;
+				for (int j = i; j < i2; j += iChannels) {
+					qtractorAudioPeakFile::Frame *pOldFrame = &pPeakFrames[j + k];
 					if (pNewFrame->max < pOldFrame->max)
 						pNewFrame->max = pOldFrame->max;
 					if (pNewFrame->min < pOldFrame->min)
@@ -970,6 +968,7 @@ qtractorAudioPeakFile::Frame *qtractorAudioPeak::peakFrames (
 						pNewFrame->rms = pOldFrame->rms;
 				}
 			}
+			n += iChannels;
 			i = i2;
 		}
 		// New-indirect frame buffer length...
