@@ -1,7 +1,7 @@
 // qtractorEngineCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -303,6 +303,9 @@ bool qtractorBusCommand::updateBus (void)
 	// May close now the bus...
 	m_pBus->close();
 
+	// Have some time slack...
+	pSession->stabilize();
+
 	// Set new properties...
 	m_pBus->setBusName(m_sBusName);
 	m_pBus->setBusMode(m_busMode);
