@@ -1156,7 +1156,7 @@ void qtractorMixerRackWidget::contextMenuEvent (
 void qtractorMixerRackWidget::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
 	if (!m_pWorkspaceWidget->rect().contains(pMouseEvent->pos()))
-		m_pRack->setSelectedStrip(nullptr);
+		m_pRack->mixer()->setCurrentTrack(nullptr);
 
 	QScrollArea::mousePressEvent(pMouseEvent);
 }
@@ -1354,9 +1354,6 @@ void qtractorMixerRack::clear (void)
 // Selection stuff.
 void qtractorMixerRack::setSelectedStrip ( qtractorMixerStrip *pStrip )
 {
-	if (m_pSelectedStrip == pStrip)
-		return;
-
 	if (m_pSelectedStrip)
 		m_pSelectedStrip->setSelected(false);
 
@@ -1375,9 +1372,12 @@ void qtractorMixerRack::setSelectedStrip ( qtractorMixerStrip *pStrip )
 
 void qtractorMixerRack::setSelectedStrip2 ( qtractorMixerStrip *pStrip )
 {
-	if (m_pSelectedStrip2 == m_pSelectedStrip)
+	if (pStrip && pStrip == m_pSelectedStrip)
 		return;
 
+	if (m_pSelectedStrip2 && m_pSelectedStrip2 == m_pSelectedStrip)
+		m_pSelectedStrip2 = nullptr;
+
 	if (m_pSelectedStrip2)
 		m_pSelectedStrip2->setSelected(false);
 
@@ -1798,5 +1798,29 @@ void qtractorMixer::keyPressEvent ( QKeyEvent *pKeyEvent )
 }
 
 
+// Current selected output bus (usually an Aux-Send target) accessors.
+void qtractorMixer::setSelectedOutputBus ( qtractorBus *pOutputBus )
+{
+	qtractorMixerStrip *pOutputStrip2 = nullptr;
+
+	if (pOutputBus && (pOutputBus->busMode() & qtractorBus::Output))
+		pOutputStrip2 = m_pOutputRack->findStrip(pOutputBus->monitor_out());
+
+	m_pOutputRack->setSelectedStrip2(pOutputStrip2);
+}
+
+
+qtractorBus *qtractorMixer::selectedOutputBus (void) const
+{
+	qtractorBus *pOutputBus = nullptr;
+
+	qtractorMixerStrip *pOutputStrip2 = m_pOutputRack->selectedStrip2();
+	if (pOutputStrip2)
+		pOutputBus = pOutputStrip2->bus();
+
+	return pOutputBus;
+}
+
+
 // end of qtractorMixer.cpp
 
