@@ -1,7 +1,7 @@
 // qtractorRubberBand.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ class qtractorRubberBand : public QRubberBand
 public:
 
 	// Constructor.
-	qtractorRubberBand(Shape shape, QWidget *widget = 0, int thick = 1);
+	qtractorRubberBand(Shape shape, QWidget *widget = nullptr, int thick = 1);
 	// Destructor.
 	~qtractorRubberBand();
 
