@@ -66,6 +66,7 @@ qtractorSessionForm::qtractorSessionForm ( QWidget *pParent )
 		QFontMetrics(font2).height());
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+	// Some conveniency cleaner helper...
 	m_ui.SessionDirComboBox->lineEdit()->setClearButtonEnabled(true);
 #endif
 
@@ -74,7 +75,7 @@ qtractorSessionForm::qtractorSessionForm ( QWidget *pParent )
 		new QIntValidator(m_ui.SampleRateComboBox));
 
 	// Fill-up snap-per-beat items...
-	const QIcon snapIcon(":/images/itemBeat.png");
+	const QIcon& snapIcon = QIcon::fromTheme("itemBeat");
 	const QStringList& snapItems = qtractorTimeScale::snapItems();
 	QStringListIterator snapIter(snapItems);
 	m_ui.SnapPerBeatComboBox->clear();
@@ -82,7 +83,7 @@ qtractorSessionForm::qtractorSessionForm ( QWidget *pParent )
 //	snapIter.toFront();
 	if (snapIter.hasNext())
 		m_ui.SnapPerBeatComboBox->addItem(
-			QIcon(":/images/itemNone.png"), snapIter.next());
+			QIcon::fromTheme("itemNone"), snapIter.next());
 	while (snapIter.hasNext())
 		m_ui.SnapPerBeatComboBox->addItem(snapIcon, snapIter.next());
 //	m_ui.SnapPerBeatComboBox->insertItems(0, snapItems);
