@@ -10,7 +10,7 @@
 //-----------------------------------------------------------------------------
 // This file is part of a Steinberg SDK. It is subject to the license terms
 // in the LICENSE file found in the top-level directory of this distribution
-// and at www.steinberg.net/sdklicenses. 
+// and at www.steinberg.net/sdklicenses.
 // No part of the SDK, including this file, may be copied, modified, propagated,
 // or distributed except according to the terms contained in the LICENSE file.
 //-----------------------------------------------------------------------------
@@ -276,14 +276,15 @@ struct RefCounted
 
 	uint32 PLUGIN_API release ()
 	{
-		if (--refCount == 0)
+		auto rc = --refCount;
+		if (rc == 0)
 		{
 			destroyInstance ();
 			refCount = -1000;
 			delete this;
-			return 0;
+			return uint32 ();
 		}
-		return refCount;
+		return rc;
 	}
 
 //------------------------------------------------------------------------
@@ -466,5 +467,5 @@ using FUnknownImpl::cast;
 using FUnknownImpl::getTUID;
 
 //------------------------------------------------------------------------
-} // U
-} // Steinberg
+} // namespace U
+} // namespace Steinberg
